﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace PB069.Lecture4.FormsAndBasicControls
{
    public partial class MainForm : Form
    {
        // datové položky, do kterých uložíme nastavení z dialogu
        private string username;
        private bool czechLanguage = true;
        private bool englishLanguage;
        private bool useExclamationMark;


        public MainForm()
        {
            InitializeComponent();
        }

        private void sayHelloButton_Click(object sender, EventArgs e)
        {
            SayHelloDialogForm frm = new SayHelloDialogForm();

            RetrieveControlsValues(frm);

            if (frm.ShowDialog() == DialogResult.OK)
            {
                SaveControlsValues(frm);
                SetSettingsToLabel();

                ShowMessage();
            }
        }



        // Uložení nastavení dialog do datových položek hlavního formuláře,
        // abychom mohli při další zobrazení dialogu uživateli zobrazit
        // jeho poslední volby,
        private void SaveControlsValues(SayHelloDialogForm frm)
        {
            username = frm.UserName;
            czechLanguage = frm.UseCzechLanguage;
            englishLanguage = frm.UseEnglishLanguage;
            useExclamationMark = frm.AddExclamationMark;
        }

        // Nastaví dialogu poslední použité hodnoty.
        private void RetrieveControlsValues(SayHelloDialogForm frm)
        {
            frm.UserName = username;
            frm.UseCzechLanguage = czechLanguage;
            frm.UseEnglishLanguage = englishLanguage;
            frm.AddExclamationMark = useExclamationMark;
        }

        // zobrazí pozdrav uživateli
        private void ShowMessage()
        {
            string messageFormat;
            if (czechLanguage)
            {
                messageFormat = "Ahoj {0}";
            }
            else if (englishLanguage)
            {
                messageFormat = "Hello {0}";
            }
            else
            {
                messageFormat = "Oops. Nebyl vybraný žádný jazyk.";
            }

            if (useExclamationMark)
            {
                messageFormat += "!";
            }

            string message = string.Format(messageFormat, username);
            MessageBox.Show(message);
        }

        // nastaví popisky na formuláři podle hodnot zvolených v dialogu
        private void SetSettingsToLabel()
        {
            lastUsedNameLabel.Text = username;
            lastUsedLanguagesLabel.Text = "";
            if (czechLanguage)
            {
                lastUsedLanguagesLabel.Text += "Česky";
            }
            if (englishLanguage)
            {
                if (lastUsedLanguagesLabel.Text != "")
                {
                    lastUsedLanguagesLabel.Text += ", ";
                }
                lastUsedLanguagesLabel.Text += "English";
            }
            lastUsedExclamationMarkLabel.Text = useExclamationMark ? "Yes" : "No";
        }
    }
}
